@@ -1,10 +1,15 @@
-from pydantic import SecretStr
+from pydantic import SecretStr, PostgresDsn
 from pydantic_settings import BaseSettings
 
 
 class CommonSettings(BaseSettings):
     logging_level: str = 'INFO'
     logging_format: str = '%(asctime)s [%(levelname)s] %(name)s: %(message)s'
+    logging_formatter: str = 'default'
+
+
+class DBSettings(BaseSettings):
+    db_dsn: PostgresDsn | None = None
 
 
 class S3Settings(BaseSettings):
@@ -19,4 +24,5 @@ class S3Settings(BaseSettings):
 
 
 settings = CommonSettings()
+db_settings = DBSettings()
 s3_settings = S3Settings()
